/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.am.model;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * a TemplateDefintion#url and a TaskId representing a request to download a VirtualMachineTemplat
 */
@XmlType
@XmlRootElement(name = "templateRequest")
public class TemplateRequest extends SingleResourceTransportDto
{
    private static final long serialVersionUID = -2974958775603368089L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.templaterequest+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private String taskId;

    private String ovfId;

    /**
     * Target desired name for promoted instance instance (Only set if ''ovfId'' is a template instance
     * identifier)
     */
    private String promotedOvfId;
    
    private String promotedName;
    
    public String getPromotedName()
    {
        return promotedName;
    }

    public void setPromotedName(String promotedName)
    {
        this.promotedName = promotedName;
    }

    public String getPromotedOvfId()
    {
        return promotedOvfId;
    }

    public void setPromotedOvfId(String promotedOvfId)
    {
        this.promotedOvfId = promotedOvfId;
    }

    public String getTaskId()
    {
        return taskId;
    }

    public void setTaskId(final String taskId)
    {
        this.taskId = taskId;
    }

    public String getOvfId()
    {
        return ovfId;
    }

    public void setOvfId(final String ovfId)
    {
        this.ovfId = ovfId;
    }

    @Override
    public String getMediaType()
    {
        return MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
