/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * 
 */
package com.abiquo.am.model.error;


public class AMException extends RuntimeException
{

    final AMError error;

    public AMError getError()
    {
        return error;
    }

    public AMException(final AMError error)
    {
        super(error.getMessage());
        this.error = error;
    }

    public AMException(final AMError error, final String msg)
    {
        super(String.format("%s\nDetail:\n%s", error.getMessage(), msg));
        this.error = error;
    }

    public AMException(final AMError error, final String msg, final Throwable th)
    {
        super(String.format("%s\nDetail:\n%s", error.getMessage(), msg), th);
        this.error = error;
    }

    public AMException(final AMError error, final Throwable th)
    {
        super(error.getMessage(), th);
        this.error = error;
    }

    public static String getErrorMessage(final Integer statusCode, final String fileUrl)
    {

        if (statusCode == 401)
        {
            return String.format("[Unauthorized] You might not have permissions to read "
                + "the file or folder at the following location: %s", fileUrl);
        }
        else if (statusCode == 403)
        {
            return String.format("[Forbidden] You might not have permissions to read "
                + "the file or folder at the following location: %s", fileUrl);
        }
        else if (statusCode == 404)
        {
            return String.format(
                "[Not Found] The file or folder at the location: %s does not exist", fileUrl);
        }
        else
        {
            return String.format("%d -  at : %s", statusCode, fileUrl);
        }
    }

}
